# encoding:utf-8
import urllib.request
import urllib.parse
import json
APPKEY='631c5a5b9992bd74'
APPSECRET='eS0iNTaMdI5mgRew8JkrVqUB7mG1MytS'
API_URL='http://api.jisuapi.com/astro'

def get_all_xingzuo():
    data = {}
    data['appkey'] = APPKEY
    url_values = urllib.parse.urlencode(data)
    url = API_URL + '/all?' + url_values
    result = urllib.request.urlopen(url)
    jsonarr = json.loads(result.read())
    return jsonarr['result']


def _get_xingzuo_fortune(name='',today=False,tomorrow=False,week=False,month=False,year=False):
    if name == '':
        return -1
    if len(name) == 2:
        name += '座'
    xingzuo_dict = {
        '白羊座':1,
        '金牛座':2,
        '双子座':3,
        '巨蟹座':4,
        '狮子座':5,
        '处女座':6,
        '天秤座':7,
        '天蝎座':8,
        '射手座':9,
        '摩羯座':10,
        '水瓶座':11,
        '双鱼座':12
    }
    if name not in xingzuo_dict:
        return -1
    data = {}
    data['appkey'] = APPKEY
    data['astroid'] = xingzuo_dict[name]
    url_values = urllib.parse.urlencode(data)
    url = API_URL + '/fortune?' + url_values
    result = urllib.request.urlopen(url)
    jsonarr = json.loads(result.read())
    res = jsonarr['result']
    if today:
        res_today = res['today']
        if 'summary' in res_today:
            del res_today['summary']
        if 'money' in res_today:
            del res_today['money']
        if 'career' in res_today:
            del res_today['career']
        if 'love' in res_today:
            del res_today['love']
        if 'health' in res_today:
            del res_today['health']
        return res_today
    elif tomorrow:
        res_tomorrow = res['tomorrow']
        if 'summary' in res_tomorrow:
            del res_tomorrow['summary']
        if 'money' in res_tomorrow:
            del res_tomorrow['money']
        if 'career' in res_tomorrow:
            del res_tomorrow['career']
        if 'love' in res_tomorrow:
            del res_tomorrow['love']
        if 'health' in res_tomorrow:
            del res_tomorrow['health']
        return res_tomorrow
    elif week:
        return res['week']
    elif month:
        return res['month']
    elif year:
        return res['year']
    else:
        return res

'''
{'date': '2017-12-29', 'presummary': '很渴望感情，喜欢去追求外地的异性朋友，已婚者，非常关爱对方，财运容易暗中很好。', 'star': '狮子座', 'color': '红色', 'number': '5'}
'''
def get_today_fortune(name=''):
    res = _get_xingzuo_fortune(name,today=True)

    return res


'''
{'date': '2017-12-30', 'presummary': '今天的双子会特别有慧根，对宗教玄学方面的东西会比较敏感。同时，也是比较忙碌的一天，工作运也很不错。', 'star': '摩羯座', 'color': '橙色', 'number': '1'}
'''
def get_tomorrow_fortune(name=''):
    res = _get_xingzuo_fortune(name,tomorrow=True)
    return res


'''
{'date': '2017-12-24~12-30', 'money': '财运一般。会有一些社会应酬。', 'career': '非常努力的工作，只为了能有更好的内部提升的机会。', 'love': '有伴的，想结婚了。但是在结婚的问题，容易跟恋人意见不合。', 'health': '注意身材，容易发胖&nbsp;。', 'job': '求职的关键是所求工作可以证明自己的能力，让恋人对你印像改观。'}
'''
def get_week_fortune(name=''):
    res = _get_xingzuo_fortune(name,week=True)
    return res


'''
{'date': '2017-12', 'summary': '感情运佳。伴侣关系发展良好，喜欢陪伴对方、和对方聊天，责任感增强。合作关系也有长足的进步。工作运上升，做事更有效率，与同事、下属关系良好。水星逆行期间，思考表达会受到影响，电子数据注意备份，出行注意交通安全。', 'money': '正财运不错，随工作成绩的提升而增加。', 'career': '合作关系对你的工作有助力，做事更注重结果，之前处理不好的问题得到解决，但是沟通要多加注意，受水星逆行影响，可能会出现信息延迟的现象，避免说话太多随意。', 'love': '有伴的人，感情发展不错，注意沟通上的误会。单身的人，有机会在聚会活动中认识到喜欢的人或者是经由长辈介绍认识。', 'health': '双子女们需要注意妇科问题，避免工作过度劳累。'}
'''

def get_month_fortune(name=''):
    res = _get_xingzuo_fortune(name,month=True)
    return res


'''
{'date': '2017', 'summary': '大局初定&nbsp;唯我精彩对双子座来说，未来一年将是格局初定轮廓，勇敢表现自我的一年。土星已经在双子座的人际合作宫位停留两年，逼着双子们不得不以高标准严要求提升自己，不知不觉中已经脱胎换骨，到达自己都不曾想过的高度。而在土星停留对宫的最后一年，你将继续借力打力，通过合作助力进入更高的层次和圈子。与此同时，前三季度木星将会在表现宫内持续发力，让你们的人生绝对不乏精彩，不论是事业还是感情都不缺故事。持续数月的木冥刑也会让你在感情路上面临选择，如何与另一半找到共同的价值观是感情关系能否维持下去的关键因素。2017年，你们也将基本完成个人性格和认知的整合，选择最合适的领域成为所有人都无法忽略的新星，事业脉络将更加清晰，原有的纷纷扰扰和诸多插曲都可以逐渐平息，你所需要做的只是坚定自己的内心，不要被花花世界模糊双眼，明白到底自己的优势在哪里，选定最恰当的方向集中发力才能最快完成个人进阶。', 'money': '未来一年，双子座的正财运还能保持相对不错的水平，尤其是企业家和自雇业者很容易获得重要的订单而因此收入大增，但也要注意受结款周期影响，有些钱并不能马上到账，如果因此提前消费，则可能出现现金流周转不畅的问题。上班族则可以考虑利用自身特长承接私单或是尝试帮人筹备各类聚会晚会的活动策划类工作，也会有意外惊喜。除此之外，因为今年木星一直到10月10日之前都会停留在投资宫内，这也会让双子座有强烈的投资冲动，但因为木冥刑的持续作用，要特别注意关键时刻突生变故，若能考虑与人合作投资，或是多听从周围专家型朋友的意见才比较有机会真正地落袋为安。相对而言，2月底将是一个更容易通过升职实现加薪的时段，或是因为产品获得认可而实现个人资产增值。春节之前和6月之后投资运会更加理想，其它时候宜以长线投资为主。', 'career': '在过去一年中，因为日月食一直在淬炼着你们的事业宫，也令很多双子座面临着事业的动荡和挑战，过多不相干的事情难免让你们对工作有些失去热情，只想过好自己的小日子。但这样的动荡会随着2月底近年来最后一次双鱼座食相的结束而终于结束，职场发展将重新进入稳定上行区间。你将有机会在年后快速找到自己的方向和位置，然后通过合作方式稳固自身地位，并有机会再度突破天花板，进入一个更加上层的圈子。与此同时，你也应该抓住诸多突然出现的表现机会努力展现个人特色与能力，以个人魅力获得更多合作与合约，形成良好正循环，将木星天秤的力量最大发挥。对企业家和自雇业者而言，创新无疑是创造话题的最佳方式，只要敢于表现就可能被更大的公司和平台看中获得足以让公司脱胎换骨的重要合约和潜力合作对象。打工族也应振奋精神，抓住现有机会表现自己，让上层领导觉察到你的诸多特长和长袖善舞就将有更好的机会获得提升。', 'love': '木星进入双子座的感情宫将不仅给你们带来诸多高帅多金的对象可选，最难能可贵的是这些对象还都个个真心，只要你们愿意，对方随时可以巨型钻戒奉上，郑重进入结婚流程。对你们而言，最困难的可能反而是如何在诸多优质对象中做出取舍，选择那个你真正想与他共度一生的人，以及觉察到双方在价值观上的差异，找到平衡点实现殊途同归。很多双子座在年前就会有比较明确的对象出现，但若没在春节间定下，则可能在年后横生枝节，或是自己三心二意，或是对方因为事务繁忙而无暇感情，好在今年感情主导权都在你的手中，如果你并不能完全确定自己的心意，也可以利用整个上半年多加筛选，并在生日前后做出决定。对那些有拖延症和贪多症的双子座而言，最迟也应在8月底前定下好的姻缘，否则之后则可能感情变淡渐行渐远。有伴的双子座今年也将鹣鲽情深，在共患难中感情愈加弥坚，更是怀孕生子的最佳时机。在此也要珍重叮嘱各位双子座：珍惜美好时光，好运过期不候。'}
'''

def get_year_fortune(name=''):
    res = _get_xingzuo_fortune(name,year=True)
    return res


'''
{'astroid': '3', 'astroname': '双子座', 'year': {'date': '2017', 'summary': '大局初定&nbsp;唯我精彩对双子座来说，未来一年将是格局初定轮廓，勇敢表现自我的一年。土星已经在双子座的人际合作宫位停留两年，逼着双子们不得不以高标准严要求提升自己，不知不觉中已经脱胎换骨，到达自己都不曾想过的高度。而在土星停留对宫的最后一年，你将继续借力打力，通过合作助力进入更高的层次和圈子。与此同时，前三季度木星将会在表现宫内持续发力，让你们的人生绝对不乏精彩，不论是事业还是感情都不缺故事。持续数月的木冥刑也会让你在感情路上面临选择，如何与另一半找到共同的价值观是感情关系能否维持下去的关键因素。2017年，你们也将基本完成个人性格和认知的整合，选择最合适的领域成为所有人都无法忽略的新星，事业脉络将更加清晰，原有的纷纷扰扰和诸多插曲都可以逐渐平息，你所需要做的只是坚定自己的内心，不要被花花世界模糊双眼，明白到底自己的优势在哪里，选定最恰当的方向集中发力才能最快完成个人进阶。', 'money': '未来一年，双子座的正财运还能保持相对不错的水平，尤其是企业家和自雇业者很容易获得重要的订单而因此收入大增，但也要注意受结款周期影响，有些钱并不能马上到账，如果因此提前消费，则可能出现现金流周转不畅的问题。上班族则可以考虑利用自身特长承接私单或是尝试帮人筹备各类聚会晚会的活动策划类工作，也会有意外惊喜。除此之外，因为今年木星一直到10月10日之前都会停留在投资宫内，这也会让双子座有强烈的投资冲动，但因为木冥刑的持续作用，要特别注意关键时刻突生变故，若能考虑与人合作投资，或是多听从周围专家型朋友的意见才比较有机会真正地落袋为安。相对而言，2月底将是一个更容易通过升职实现加薪的时段，或是因为产品获得认可而实现个人资产增值。春节之前和6月之后投资运会更加理想，其它时候宜以长线投资为主。', 'career': '在过去一年中，因为日月食一直在淬炼着你们的事业宫，也令很多双子座面临着事业的动荡和挑战，过多不相干的事情难免让你们对工作有些失去热情，只想过好自己的小日子。但这样的动荡会随着2月底近年来最后一次双鱼座食相的结束而终于结束，职场发展将重新进入稳定上行区间。你将有机会在年后快速找到自己的方向和位置，然后通过合作方式稳固自身地位，并有机会再度突破天花板，进入一个更加上层的圈子。与此同时，你也应该抓住诸多突然出现的表现机会努力展现个人特色与能力，以个人魅力获得更多合作与合约，形成良好正循环，将木星天秤的力量最大发挥。对企业家和自雇业者而言，创新无疑是创造话题的最佳方式，只要敢于表现就可能被更大的公司和平台看中获得足以让公司脱胎换骨的重要合约和潜力合作对象。打工族也应振奋精神，抓住现有机会表现自己，让上层领导觉察到你的诸多特长和长袖善舞就将有更好的机会获得提升。', 'love': '木星进入双子座的感情宫将不仅给你们带来诸多高帅多金的对象可选，最难能可贵的是这些对象还都个个真心，只要你们愿意，对方随时可以巨型钻戒奉上，郑重进入结婚流程。对你们而言，最困难的可能反而是如何在诸多优质对象中做出取舍，选择那个你真正想与他共度一生的人，以及觉察到双方在价值观上的差异，找到平衡点实现殊途同归。很多双子座在年前就会有比较明确的对象出现，但若没在春节间定下，则可能在年后横生枝节，或是自己三心二意，或是对方因为事务繁忙而无暇感情，好在今年感情主导权都在你的手中，如果你并不能完全确定自己的心意，也可以利用整个上半年多加筛选，并在生日前后做出决定。对那些有拖延症和贪多症的双子座而言，最迟也应在8月底前定下好的姻缘，否则之后则可能感情变淡渐行渐远。有伴的双子座今年也将鹣鲽情深，在共患难中感情愈加弥坚，更是怀孕生子的最佳时机。在此也要珍重叮嘱各位双子座：珍惜美好时光，好运过期不候。'}, 'month': {'date': '2017-12', 'summary': '感情运佳。伴侣关系发展良好，喜欢陪伴对方、和对方聊天，责任感增强。合作关系也有长足的进步。工作运上升，做事更有效率，与同事、下属关系良好。水星逆行期间，思考表达会受到影响，电子数据注意备份，出行注意交通安全。', 'money': '正财运不错，随工作成绩的提升而增加。', 'career': '合作关系对你的工作有助力，做事更注重结果，之前处理不好的问题得到解决，但是沟通要多加注意，受水星逆行影响，可能会出现信息延迟的现象，避免说话太多随意。', 'love': '有伴的人，感情发展不错，注意沟通上的误会。单身的人，有机会在聚会活动中认识到喜欢的人或者是经由长辈介绍认识。', 'health': '双子女们需要注意妇科问题，避免工作过度劳累。'}, 'week': {'date': '2017-12-24~12-30', 'money': '财运一般。会有一些社会应酬。', 'career': '非常努力的工作，只为了能有更好的内部提升的机会。', 'love': '有伴的，想结婚了。但是在结婚的问题，容易跟恋人意见不合。', 'health': '注意身材，容易发胖&nbsp;。', 'job': '求职的关键是所求工作可以证明自己的能力，让恋人对你印像改观。'}, 'today': {'date': '2017-12-29', 'presummary': '很渴望感情，喜欢去追求外地的异性朋友，已婚者，非常关爱对方，财运容易暗中很好。', 'star': '狮子座', 'color': '红色', 'number': '5', 'summary': '3', 'money': '2', 'career': '3', 'love': '3', 'health': '4'}, 'tomorrow': {'date': '2017-12-30', 'presummary': '今天的双子会特别有慧根，对宗教玄学方面的东西会比较敏感。同时，也是比较忙碌的一天，工作运也很不错。', 'star': '摩羯座', 'color': '橙色', 'number': '1', 'summary': '1', 'money': '2', 'career': '2', 'love': '1', 'health': '4'}}
'''
def get_fortune_info(name=''):
    res = _get_xingzuo_fortune(name)
    return res
